biom.table.Table.nonzero_counts — biom-format.org

# biom-format.org

## biom.table.Table.nonzero_counts

`Table.` `nonzero_counts`(axis, binary=False)

  Get nonzero summaries about an axis

  Parameters: | axis : {‘sample’, ‘observation’, ‘whole’} The axis on which to count nonzero entries binary : bool, optional Defaults to `False`. If `False`, return number of nonzero entries. If `True`, sum the values of the entries.
  Returns: | numpy.array Counts in index order to the axis